/**
 * Timeline 기능을 수행하는 클래스
 * @class Timeline 기능을 수행하는 클래스
 */
var Timeline =
{
	public_time_line_list : null,
	user_timeline_list : null,
	friends_timeline_list : null,
	mentions_list : null,
	
	friends_timeline_return_func : null,
	friends_timeline_check_table : Array(),
	
	user_timeline_return_func : null,
	critical_error_func : null,
	
	mention_return_func : null,
	
	update_status_return_func : null,
	reply_status_return_func : null,
	reply_status_error_func : null,
	
	update_status_error_func : null,
	
	COUNT_IN_PAGE : 4, //트위터 API에서 한페이지의 status 개수
	ONCE_COUNT : 100 //한번에 받아 올 데이터 양
}

//실제 Public Timeline을 데이터를 받는 곳.
Timeline.OnPublicTimelineReceive = function(httpRequest)
{
	alert("Timeline.OnPublicTimelineReceive()");
	Test(httpRequest, null, "httpRequest가 null");
	
	this.public_timeline_list = StatusMaker.MakeStatusList(httpRequest.responseXML);
}

//실제 User Timeline을 데이터를 받는 곳.
Timeline.OnUserTimelineReceive = function(httpRequest, load_no)
{
	alert("Timeline.OnUserTimelineReceive()");
	Test(httpRequest, null, "httpRequest가 null");

	if (!httpRequest || httpRequest.status == 420) {
		if(Timeline.user_timeline_return_func)
			Timeline.user_timeline_return_func(TwitterDefine.Event.Fail);
		return;
	}

	Timeline.user_timeline_list = StatusUserMaker.MakeStatusUserList(httpRequest.responseXML);
	
	if(Timeline.user_timeline_return_func)
		Timeline.user_timeline_return_func(Timeline.user_timeline_list, load_no);
}

//User Timeline Error
Timeline.OnCriticalError = function(httpRequest)
{
	alert("Timeline.OnCriticalError()");

	 //interactive remote start
	 iRemoteTW.messgPopup("", SID_ALERT_NETWORKERROR_MSG); 
	 //interactive remote end
	 
	MessageBoxMgr.Show("", SID_ALERT_NETWORKERROR_MSG,
						   function()
						   {
								widgetAPI.sendReturnEvent();
						   });
	
	//if(Timeline.critical_error_func)
	//	Timeline.critical_error_func();
}

//실제 Friends Timeline을 데이터를 받는 곳.
Timeline.OnFriendsTimelineReceive = function(httpRequest, load_no)
{
	alert("Timeline.OnFriendsTimelineReceive()");
	Test(httpRequest, null, "httpRequest가 null");
	
	Timeline.friends_timeline_list = StatusUserMaker.MakeStatusUserList(httpRequest.responseXML);
	if(Timeline.friends_timeline_return_func)
		Timeline.friends_timeline_return_func(Timeline.friends_timeline_list, load_no);
}

//Friends Timeline 얻기
Timeline.GetFriendsTimeline = function(load_no, async)
{
	alert("Timeline.GetFriendsTimeline()");
	TwitterConsumer.Init("get", FRIENDS_TIMELINE_URL+ "?count=" + this.ONCE_COUNT + "&page=" + load_no);
	TwitterConsumer.SetAdditionalInfo(load_no);
	TwitterConsumer.SetOnErrorReceive(Timeline.OnCriticalError);
	TwitterConsumer.SetOnReceive(Timeline.OnFriendsTimelineReceive);
	TwitterConsumer.Request(async);
}

//Public Timeline 얻기
Timeline.GetPublicTimeline = function()
{
	alert("Timeline.GetPublicTimeline()");
	TwitterConsumer.Init("get", PUBLIC_TIMELINE_URL);
	TwitterConsumer.SetOnErrorReceive(Timeline.OnCriticalError);
	TwitterConsumer.SetOnReceive(Timeline.OnPublicTimelineReceive);
	TwitterConsumer.Request();
}

Timeline.SetUserTimelineReturnFunc = function(return_callback)
{
	alert("Timeline.SetUserTimelineErrorFunc()");
	this.user_timeline_return_func = return_callback;
}

//User Timeline 얻기
Timeline.GetUserTimeline = function(id, load_no, async)
{
	alert("Timeline.GetUserTimeline()");
	TwitterConsumer.Init("get", USER_TIMELINE_URL+ "?count=" + this.ONCE_COUNT + "&page=" + load_no + "&id=" + id);
	TwitterConsumer.SetAdditionalInfo(load_no);
//	TwitterConsumer.SetOnErrorReceive(Timeline.OnCriticalError);
	TwitterConsumer.SetOnErrorReceive(Timeline.OnUserTimelineReceive);
	TwitterConsumer.SetOnReceive(Timeline.OnUserTimelineReceive);
	TwitterConsumer.Request(async);
}

//FriendsTimeline의 리턴함수를 등록하는 함수
Timeline.SetFriendsTimelineReturnFunc = function(return_callback)
{
	alert("Timeline.SetFriendsTimelineReturnFunc");
	this.friends_timeline_return_func = return_callback;
}

//Friends Timeline List 저장해놓기
Timeline.SetFriendsTimelineList = function(index, list)
{
	alert("Timeline.SetFriendsTimelineList");
	this.friends_timeline_check_table[index] = list;
}

//Friends Timeline List 저장해 놓은 것 얻기
Timeline.GetFriendsTimelineList = function(index)
{
	return this.friends_timeline_check_table[index];
}

Timeline.GetFriendsTimelineListCount = function(index)
{
	return this.friends_timeline_check_table.length;
}

//Mention 얻기
Timeline.GetMentions = function(load_no, async)
{
	alert("Timeline.GetMentions() "+load_no);
	TwitterConsumer.Init("get", MENTIONS_URL + "?count="+this.ONCE_COUNT+"&page="+load_no);
	TwitterConsumer.SetAdditionalInfo(load_no);
	TwitterConsumer.SetOnReceive(Timeline.OnMentionsReceive);
	TwitterConsumer.SetOnErrorReceive(Timeline.OnCriticalError);
	TwitterConsumer.Request(async);
}

Timeline.SetGetMentionsReturnFunc = function(func)
{
	this.mention_return_func = func;
}

//실제 Mention 데이터를 받는 곳.
Timeline.OnMentionsReceive = function(httpRequest, load_no)
{
	alert("Timeline.OnMentionsReceive()");
	Test(httpRequest, null, "httpRequest가 null");
	
	Timeline.mentions_list = StatusUserMaker.MakeStatusUserList(httpRequest.responseXML);
	
	if (Timeline.mention_return_func) 
	{
		Timeline.mention_return_func(Timeline.mentions_list, load_no);
	}
}

Timeline.SetUpdateStatusReturnFunc = function(func)
{
	this.update_status_return_func = func;
}

Timeline.SetUpdateStatusErrorFunc = function(func)
{
	this.update_status_error_func = func;
}

//Status를 포스팅 한 후 성공하면 이 함수 호출 됨  
Timeline.OnUpdateStatus = function(httpRequest)
{
	alert("Timeline.OnUpdateStatus()");

	if(Timeline.update_status_return_func)
		Timeline.update_status_return_func();
	
}

//Status를 포스팅 한 후 성공하면 이 함수 호출 됨  
Timeline.OnUpdateStatusError = function(httpRequest)
{
	alert("Timeline.OnUpdateStatus()");

	if(Timeline.update_status_error_func)
		Timeline.update_status_error_func();
	
}

//Status를 포스팅한다.
Timeline.UpdateStatus = function(text)
{
	alert("Timeline.UpdateStatus()");
	//TwitterConsumer.Init("post", STATUS_UPDATE_URL + "?status=" + text,
	// 				  ID, PASSWORD);
	
	TwitterConsumer.Init("post", STATUS_UPDATE_URL + "?status=" + Util.encodeURI(text));
	TwitterConsumer.SetOnReceive(Timeline.OnUpdateStatus);
	TwitterConsumer.SetOnErrorReceive(Timeline.OnUpdateStatusError);
	TwitterConsumer.Request();
}

////////////////////////////////////////////////////
Timeline.SetReplyStatusReturnFunc = function(func)
{
	this.reply_status_return_func = func;
}

Timeline.SetReplyStatusErrorFunc = function(func)
{
	this.reply_status_error_func = func;
}

//Status를 reply한다.
Timeline.ReplyStatus = function(status_id, text)
{
	alert("Timeline.UpdateStatus()");
	alert(STATUS_UPDATE_URL + "?status=" + text + "&in_reply_to_status_id=" + status_id);
//	TwitterConsumer.Init("post", STATUS_UPDATE_URL + "?status=" +  Util.encodeURI(text) + "&in_reply_to_status_id=" + Util.encodeURI(status_id));
	TwitterConsumer.Init("post", STATUS_UPDATE_URL + "?status=" +  Util.encodeURI(text));
	TwitterConsumer.SetOnReceive(Timeline.OnReplyStatus);
	TwitterConsumer.Request();
}

//Status reply를 한 후 성공하면 이 함수 호출 됨  
Timeline.OnReplyStatus = function(httpRequest)
{
	alert("Timeline.OnReplyStatus()");
	alert("Reply 성공!");	
	
	if(Timeline.reply_status_return_func)
		Timeline.reply_status_return_func();
}

//Status reply를 한 후 실패면 이 함수 호출 됨  
Timeline.OnReplyStatusError = function(httpRequest)
{
	alert("Timeline.OnReplyStatusError()");
	alert("Reply 실패!");	
	
	if(Timeline.reply_status_error_func)
		Timeline.reply_status_error_func();
}
///////////////////////////////////////////////////

Timeline.PrintList = function(statuslist)
{
	Test(statuslist, null, "Timeline.PrintList의 statuslist가 null");
	if(statuslist == null)
		return;
	for (var i = 0; i < statuslist.length; i++) 
	{
		if(statuslist[i] == null)
			break;
		alert(statuslist[i].CreatedAt);
		alert(statuslist[i].Id);
		alert(statuslist[i].Text);
		alert(statuslist[i].Source);
		alert(statuslist[i].Truncated);
		alert(statuslist[i].InReplyToStatusId);
		alert(statuslist[i].InReplyToUserId);
		alert(statuslist[i].Favorited);
		alert(statuslist[i].InReplyToScreenName);
	}
}
