/**
 * Tweet상세보기를 구현한 클래스
 * @class Tweet상세보기를 구현한 클래스
 */
var DetailViewMgr = 
{
	current_index : 0,
	current_status : null,
	pre_status : null,
	COUNT_IN_PAGE : 4,
	mode : 0,
	
	button_enable_table : null,
	
	key_anchor : null
}

/**
 * 현재 모드를 얻음
 * @return {Number} 현재 모드 값, 1:Home, 3:Profile, 4:Search, 6:More
 */
DetailViewMgr.GetMode = function()
{
	return this.mode;
}

/**
 * 현재 Status 데이터를 설정한다.
 * @param {Object} status 설정할 Status 데이터
 */
DetailViewMgr.SetCurrentStatus = function(status)
{
	this.current_status = status;
}

/**
 * DetailViewMgr 초기화
 */
DetailViewMgr.Init = function()
{
	UIDetailView.Init();
	this.key_anchor = document.getElementById("DetailViewKeyAnchor");
}

/**
 * Show 함수에서 호출하는 메소드, Show함수의 초기 구성을 한다.
 * @param {Object} status Status 데이터
 * @param {Object} mode 모드값
 */
DetailViewMgr.ShowSub = function(status, mode)
{
	this.SetCurrentStatus(status);
	
	UIDetailView.SetNameToNameDiv(status.ScreenName);
	UIDetailView.SetTextToTextDiv(status.Text);
	UIDetailView.SetImageToImageDiv(status.ProfileImageUrl);
	UIDetailView.SetDatetimeToDatetimeDiv(Util.ExtractMessage(status, status.CreatedAt));
	
	alert("status.Favorited -> " + status.Favorited);
	
	TWAlert("DetailViewMgr :: ShowSub mode - " + mode);
	
	if (this.mode == TwitterDefine.From.Home || this.mode == TwitterDefine.From.People) 
	{
		//
		UIDetailView.HideBackgroundImage2();
		UIDetailView.ShowProfileText();
		this.COUNT_IN_PAGE = 4;
	}
	else if(this.mode == TwitterDefine.From.Profile)
	{
		UIDetailView.ShowBackgroundImage2();
		UIDetailView.HideProfileText();
		this.COUNT_IN_PAGE = 3;
	}
	
	this.button_enable_table = new Array();
	for(var i=0; i<this.COUNT_IN_PAGE; i++)
		this.button_enable_table[i]=true;
	
	if (this.mode == TwitterDefine.From.Search) {
		UIDetailView.SetFavoriteText();
		UIDetailView.EnabledFavorite(false);			
		this.button_enable_table[2]=false;
		UIDetailView.HideStarImage();
	}
	else {
		if (status.Favorited) {
			UIDetailView.SetUnfavoriteText();
			UIDetailView.ShowStarImage();
		}
		else {
			UIDetailView.SetFavoriteText();
			UIDetailView.HideStarImage();
		}
	}
	
//	if (status.ScreenName == ID) 
	if ((status.UserId ? status.UserId : status.Id) == TwitterMain.SessionUID) 
	{
		UIDetailView.SetDeleteText();
		UIDetailView.EnabledProfile(false);
		this.button_enable_table[3]=false;
	}
	else 
	{
		UIDetailView.SetReplyText();
		UIDetailView.EnabledProfile(true);
	}

	UIDetailView.EnabledRetweet(true);
			
	UIDetailView.SetRetweetText();
	UIDetailView.SetProfileText();
	
	HelpNavigationMgr.ShowDetailViewHelp();
	UIDetailView.Show();

	this.Focus();
		
	this.current_index = 0;
	UIDetailView.SetFocus(this.current_index);
	
	//interactive remote start
	iRemoteTW.detailView(iRemoteTW.selectedUserId);
	//interactive remote end

}

/**
 * Tweet 상세보기를 표시
 * @param {Object} status Status 데이터
 * @param {Object} mode 모드 값
 */
DetailViewMgr.Show = function(pStatus, pMode)
{
	alert("DetailViewMgr.Show()");
	
	this.mode = pMode;
	this.current_status = pStatus;
	
	this.ShowSub(pStatus, pMode);
	
	//interactive remote start
    	iRemoteTW.detailViewFlag = "1";
	//interactive remote end
  }

/**
 * Tweet 상세보기에 포커스를 줌
 */
DetailViewMgr.Focus = function()
{
	this.key_anchor.focus();
}

/**
 * Tweet 상세보기를 닫음
 */
DetailViewMgr.Hide = function()
{
	UIDetailView.Hide();
	
	//interactive remote start
    	iRemoteTW.detailViewFlag = "0";
	//interactive remote end
}

/**
 * Tweet 상세보기 버튼 포커스 위로 이동
 */
DetailViewMgr.MoveUp = function()
{
	var nOldIdx = this.current_index;
	do
	{
		this.current_index--;
		
		if(this.current_index < 0)
			this.current_index = this.COUNT_IN_PAGE-1;
	} while (!this.button_enable_table[this.current_index])	
	UIDetailView.moveFocus(nOldIdx, this.current_index);
}

/**
 * Tweet 상세보기 버튼 포커스 아래로 이동
 */
DetailViewMgr.MoveDown = function()
{
	var nOldIdx = this.current_index;
	do
	{
		this.current_index++;
		
		if(this.current_index >= this.COUNT_IN_PAGE)
			this.current_index = 0;
	} while (!this.button_enable_table[this.current_index])	
	UIDetailView.moveFocus(nOldIdx, this.current_index);
}

/**
 * Tweet 상세보기 화면에서 없앴다가 다시 화면에 표시
 */
DetailViewMgr.Refresh = function()
{
	UIDetailView.Refresh();
}

/**
 * Favorite 설정한 후 성공하면 호출되는 콜백함수
 */
DetailViewMgr.OnCreateFavoriteReturn = function()
{
	alert("DetailViewMgr.OnCreateFavoriteReturn()");
	LoadingMgr.Hide();
	HomeMgr.SetUpdate(0);
	HomeMgr.SetUpdate(2);
	
	DetailViewMgr.current_status.Favorited = true;
	
	if(DetailViewMgr.mode == 1) //Home에서 온것이면
	{
		HomeMgr.Display();
	}
	else if(DetailViewMgr.mode == 3) //Profile에서 온것이면
	{
		ProfileMgr.Display();
	}
	else if(DetailViewMgr.mode == 4) //Search에서 온것이면
	{
		//DetailViewMgr.pre_status.Favorited = true;
		SearchMgr.Display();
	}
	else if(DetailViewMgr.mode == 6) //More에서 온것이면
	{
		MoreMgr.Display();
	}
	
	UIDetailView.SetUnfavoriteText();
	DetailViewMgr.Refresh();	
	UIDetailView.ShowStarImage();
	DetailViewMgr.Focus();	
}

/**
 * Favorite 설정해제 후 성공하면 호출되는 콜백함수
 */
DetailViewMgr.OnDestroyFavoriteReturn = function()
{
	alert("DetailViewMgr.OnDestroyFavoriteReturn()");
	LoadingMgr.Hide();
	HomeMgr.SetUpdate(0);
	HomeMgr.SetUpdate(2);
	if(HomeMgr.GetMode() == 2) //Favorites 필터링이면
	{
		//var real_index = HomeMgr.GetRealIndex();
		//HomeMgr.current_favorites_list = Util.RemoveArrayElementAt(HomeMgr.current_favorites_list, real_index);
		HomeMgr.SetMode(2);
	}
	 
	DetailViewMgr.current_status.Favorited = false;
	
	if(DetailViewMgr.mode == 1) //Profile에서 온것이면
	{
		HomeMgr.Display();
	}
	else if(DetailViewMgr.mode == 3) //Profile에서 온것이면
	{
		ProfileMgr.Display();
	}
	else if(DetailViewMgr.mode == 4) //Search에서 온것이면
	{
		//DetailViewMgr.pre_status.Favorited = false;
		SearchMgr.Display();
	}
	else if(DetailViewMgr.mode == 6)
	{
		MoreMgr.Display();
	}
	UIDetailView.SetFavoriteText();
	DetailViewMgr.Refresh();
	UIDetailView.HideStarImage();
	DetailViewMgr.Focus();
}

/**
 * Favorite 설정 후 실패하면 호출되는 콜백함수
 */
DetailViewMgr.OnFavoriteReturnFailed = function()
{
	alert("DetailViewMgr.OnFavoriteReturnFailed()");

	 //interactive remote start
	 iRemoteTW.messgPopup("", SID_ALERT_NETWORKERROR_MSG); 
	 //interactive remote end
	 
	MessageBoxMgr.Show("", SID_ALERT_NETWORKERROR_MSG,
						   function()
						   {
							   	LoadingMgr.Hide();
								DetailViewMgr.Refresh();
								DetailViewMgr.Focus();
						   });
}

/**
 * Favorite 설정해제 후 실패하면 호출되는 콜백함수
 */
DetailViewMgr.OnUnfavoriteReturnFailed = function()
{
	alert("DetailViewMgr.OnFavoriteReturnFailed()");

	 //interactive remote start
	 iRemoteTW.messgPopup("", SID_ALERT_NETWORKERROR_MSG); 
	 //interactive remote end
	 
	MessageBoxMgr.Show("", SID_ALERT_NETWORKERROR_MSG,
						   function()
						   {
							   	LoadingMgr.Hide();
								DetailViewMgr.Refresh();
								DetailViewMgr.Focus();
						   });
}

/**
 * 버튼을 선택하면 실행하는 함수
 */
DetailViewMgr.Select = function()
{
	alert("DetailViewMgr.Select()");
	
	switch(this.current_index)
	{
		case 0: //Reply/Delete
        			if ((this.current_status.UserId ? this.current_status.UserId : this.current_status.Id) == TwitterMain.SessionUID) {

				//interactive remote start
				iRemoteTW.yesNoPopup(SID_DELETE_THE_SELECTED_TWEET);
				//interactive remote end
				
				YesNoPopupMgr.ShowDelete(function(return_code){
					alert("return_code -> " + return_code);
					
					if (return_code == 0) {
						DetailViewMgr.Hide();
						var mode = DetailViewMgr.GetMode();
						if (mode == 1) 
							HomeMgr.DeleteStatus();
						else 
							if (mode == 2) {}
							else 
								if (mode == 3) 
									ProfileMgr.DeleteStatus();
								else 
									if (mode == 6) 
										MoreMgr.DeleteStatus();
					}
					else {
						DetailViewMgr.Focus();
					}
				});
			}
			else {
				// Reply case
				//interactive remote start
				if(iRemoteTW.brwsrVer){
					 var showElements = null;
					showElements = {
						type : "qwerty",
						identifier : "qwertyRep",
						title : TWID_REPLY,
						onEvent : "action?reply=[$qwertyRep.value$]"
					}
					$.sfIRemote('menu', showElements);
				}
				//interactive remote end
				MultilineIME.SetReturnFocusFunc(this.key_anchor);
				MultilineIME.Show(this.current_status
					, function(pInputText){
						TwitterReply.OnEnter(DetailViewMgr.current_status.Id, pInputText, DetailViewMgr.mode, SID_REPLAY_SENT_SUCCESSFULLY)
					}
					, function(){
						TwitterReply.OnCancel(DetailViewMgr.mode)
					}
					, TWID_REPLY
					, SID_MIX_REPLY_TO.Replace(this.current_status.ScreenName) 
					, "@" + this.current_status.ScreenName + " ");
			}
			break;
		case 1: //Retweet
				//interactive remote start
				if (iRemoteTW.brwsrVer) {
					var showElements = null;
					showElements = {
						type: "qwerty",
						identifier: "qwertyRet",
						title: TWID_RETWEET_VERB,
						onEvent: "action?retweet=[$qwertyRet.value$]"
					}
					$.sfIRemote('menu', showElements);
				}
				//interactive remote end
				MultilineIME.SetReturnFocusFunc(this.key_anchor);
				MultilineIME.Show(this.current_status
					, function(pInputText){
						TwitterReply.OnEnter(DetailViewMgr.current_status.Id, pInputText, DetailViewMgr.mode, SID_TWEET_POSTED)
					}
					, function(){
						TwitterReply.OnCancel(DetailViewMgr.mode)
					}
					, TWID_RETWEET_VERB
//					, TWID_RETWEET_VERB + " to " + ID
					, ""
					, "RT @" + this.current_status.ScreenName + ": " + this.current_status.Text);
			break;
		case 2: //Favorite/Unfavorite
			LoadingMgr.Show();
			KeyHandler.FocusNoKey();
			if (!this.current_status.Favorited) 
			{
				Favorites.SetCreateFavoriteReturnFunc(DetailViewMgr.OnCreateFavoriteReturn);
				Favorites.SetCreateFavoriteErrorFunc(DetailViewMgr.OnFavoriteReturnFailed);
				Favorites.CreateFavorite(this.current_status.Id, true);
			}
			else 
			{
				Favorites.SetDestroyFavoriteReturnFunc(DetailViewMgr.OnDestroyFavoriteReturn);
				Favorites.SetDestroyFavoriteErrorFunc(DetailViewMgr.OnUnfavoriteReturnFailed);
				Favorites.DestroyFavorite(this.current_status.Id, true);
			}		
			break;
		case 3: //Profile
//			if (this.current_status.ScreenName != ID) 
			if ((this.current_status.UserId ? this.current_status.UserId : this.current_status.Id) != TwitterMain.SessionUID) 
			{
				if (this.mode == 1 || this.mode == 4) 
				{
					ProfileMgr.Show(this.current_status, function(pEvent){
						if (pEvent == TwitterDefine.Event.Success) {
							MainMenuMgr.Hide();
							DetailViewMgr.Hide();
							if (DetailViewMgr.mode == 1) 
							{
								HomeMgr.Hide();
							}
							else if (DetailViewMgr.mode == 4) 
							{
								SearchMgr.Hide();
							}
						} else {
							DetailViewMgr.Focus();
						}
					}, this.mode);
				}
			}
			break;
	}	
}

/**
 * Tweet 상세보기의 키 핸들러
 */
DetailViewMgr.KeyHandler = function()
{
	if (!CUtil.delayKey()) return;
	alert("DetailViewMgr.KeyHandler() -> KeyCode : " + event.keyCode);
	switch (event.keyCode)
	{
		case tvKey.KEY_UP:
			DetailViewMgr.MoveUp();
			break;		
		case tvKey.KEY_DOWN:
			DetailViewMgr.MoveDown();
			break;
		case tvKey.KEY_RETURN:
			widgetAPI.blockNavigation(event);
			DetailViewMgr.Hide();
			
			if (this.mode == 1) 
			{

				//interactive remote start
				iRemoteTW.onLoad();
				//interactive remote end
				
				HelpNavigationMgr.ShowHomeHelp();
				HomeMgr.Display();
				UIHome.Refresh();
				HomeMgr.Focus();
			}
			else if (this.mode == 3)
			{

				//interactive remote start
				iRemoteTW.profile();
				//interactive remote end
				
				ProfileMgr.Refresh();
				ProfileMgr.SetRightSideFocus();
			}
			else if (this.mode == 4)
			{
				//interactive remote start
				iRemoteTW.onLoad();
             			if(TopicsMgr.current_index == -1){
					iRemoteTW.newTopicSearch();
                		}
          			else{
				   iRemoteTW.topicItemSearch();
               			 }
				//interactive remote end
				
				SearchMgr.Refresh();
				SearchMgr.Focus();
			}
			else if (this.mode == 6)
			{
				//interactive remote start
				iRemoteTW.onLoad();
				iRemoteTW.myProfile();
				//interactive remote end
				
				MoreMgr.Refresh();
				MoreMgr.Focus();
			}
			break;
		case tvKey.KEY_ENTER:
			DetailViewMgr.Select();
			break;
		/*
		case tvKey.KEY_BLUE:
			this.Hide();
			MainMenuMgr.ShowHomeMenu();
			HomeMgr.Show();
			HomeMgr.Focus();
		*/
	}
}

DetailViewMgr.Reply = {
	Update : function(pTwit) {
		Timeline.SetUpdateStatusReturnFunc(HomeMgr.NewTwit.OnSuccess);
		Timeline.SetUpdateStatusErrorFunc(HomeMgr.NewTwit.OnFail);
		Timeline.UpdateStatus(pTwit);
	}
	,OnCancel : function() {
		MultilineIME.Hide();
		HomeMgr.Refresh();
		HomeMgr.Focus();
	}
	,OnSuccess : function() {

		 //interactive remote start
	 	iRemoteTW.messgPopup("", SID_REPLAY_SENT_SUCCESSFULLY); 
	 	//interactive remote end
		
		MessageBoxMgr.Show("", SID_REPLAY_SENT_SUCCESSFULLY,
		   function()
		   {
				HomeMgr.SetMode(0);	
				HomeMgr.SetUpdate(0);
				UIHome.Refresh();
				HomeMgr.Show();
		   });
	}
	,OnFail : function() {

		 //interactive remote start
	 	iRemoteTW.messgPopup("", SID_ALERT_NETWORKERROR_MSG); 
	 	//interactive remote end
		
		MessageBoxMgr.Show("", SID_ALERT_NETWORKERROR_MSG,
		   function()
		   {
				HomeMgr.SetMode(0);	
				HomeMgr.SetUpdate(0);
				UIHome.Refresh();
				HomeMgr.Show();
		   });
	}
}