/**
 * 다이렉트 메시지 카테고리에서의 글 상세보기를 구현하는 클래스
 * @class 다이렉트 메시지 카테고리에서의 글 상세보기를 구현하는 클래스
 */
var DirectMessageDetailViewMgr = 
{
	current_index : 0,
	current_status : null,
	COUNT_IN_PAGE : 3,
	mode : 0,
	
	key_anchor : null
}

/**
 * 현재 Status 데이터를 설정한다.
 * @param {Object} status 설정할 Status 데이터
 */
DirectMessageDetailViewMgr.SetCurrentStatus = function(status)
{
	this.current_status = status;
}

/**
 * DirectMessageDetailViewMgr 초기화
 */
DirectMessageDetailViewMgr.Init = function()
{
	this.key_anchor = document.getElementById("DirectMessageDetailViewKeyAnchor");
	UIDirectMessageDetailView.Init();
}

/**
 * 다이렉트 메시지 상세보기를 표시
 * @param {Object} status Status 데이터
 * @param {Object} mode 모드 값
 */
DirectMessageDetailViewMgr.Show = function(status, mode)
{
	alert("DirectMessageDetailViewMgr.Show()");
	this.mode = mode;
	this.SetCurrentStatus(status);
	
	if (this.mode == 100) //Inbox에서
	{
		UIDirectMessageDetailView.SetNameToNameDiv(status.SenderScreenName);
		UIDirectMessageDetailView.SetImageToImageDiv(status.Sender.ProfileImageUrl);
	}
	else if(this.mode == 101) //Sent에서
	{
		UIDirectMessageDetailView.SetNameToNameDiv(status.RecipientScreenName);
		UIDirectMessageDetailView.SetImageToImageDiv(status.Recipient.ProfileImageUrl);
	}
	UIDirectMessageDetailView.SetTextToTextDiv(status.Text);
	UIDirectMessageDetailView.SetDatetimeToDatetimeDiv(Util.ExtractMessageFromDirectMessage(null, status.CreatedAt));
	
	//HelpNavigationMgr.ShowDetailViewHelp();
	UIDirectMessageDetailView.Show();

	this.Focus();
		
	this.current_index = 0;
	UIDirectMessageDetailView.SetFocus(this.current_index);
}

/**
 * 다이렉트메시지 상세보기에 포커스를 줌
 */
DirectMessageDetailViewMgr.Focus = function()
{
	this.key_anchor.focus();
}

/**
 * 다이렉트메시지 상세보기를 닫음
 */
DirectMessageDetailViewMgr.Hide = function()
{
	UIDirectMessageDetailView.Hide();
}

/**
 * 다이렉트메시지 상세보기 버튼 포커스 위로 이동
 */
DirectMessageDetailViewMgr.MoveUp = function()
{
	alert("DirectMessageDetailViewMgr.MoveUp() -> " + this.current_index);
	this.current_index--;
	
	if(this.current_index < 0)
		this.current_index = this.COUNT_IN_PAGE-1;
		
	UIDirectMessageDetailView.SetFocus(this.current_index);
}

/**
 * 다이렉트메시지 상세보기 버튼 포커스 아래로 이동
 */
DirectMessageDetailViewMgr.MoveDown = function()
{
	alert("DirectMessageDetailViewMgr.MoveDown() -> " + this.current_index);
	this.current_index++;
	
	if(this.current_index >= this.COUNT_IN_PAGE)
		this.current_index = 0;
		
	UIDirectMessageDetailView.SetFocus(this.current_index);
}

/**
 * 다이렉트 메시지 상세보기 화면에서 없앴다가 다시 화면에 표시
 */
DirectMessageDetailViewMgr.Refresh = function()
{
	UIDirectMessageDetailView.Refresh();
}

/**
 * Sent 다이렉트 메시지 얻은 후 성공하면 호출되는 콜백함수1
 */
DirectMessageDetailViewMgr.OnGetSentDirectMessagesSuccessful1 = function(status_list)
{
	alert("DirectMessageDetailViewMgr.OnGetSentDirectMessagesSuccessful()");
	LoadingMgr.Hide();
	if (status_list == null) 
	{
		return;
	}
	
	DirectMessagesMgr.sent_data.CurrentUserList = status_list;
	
	DirectMessagesMgr.Focus();		
	
	//interactive remote start
	iRemoteTW.directMessage();
	//interactive remote end
}

/**
 * Sent 다이렉트 메시지 얻은 후 성공하면 호출되는 콜백함수2
 */
DirectMessageDetailViewMgr.OnGetSentDirectMessagesSuccessful2 = function(status_list)
{
	alert("DirectMessageDetailViewMgr.OnGetSentDirectMessagesSuccessful()");
	LoadingMgr.Hide();
	if (status_list == null) 
	{
		return;
	}
	
	DirectMessagesMgr.current_status_list = status_list;
	DirectMessagesMgr.Display();
	DirectMessagesMgr.Focus();
}

/**
 * 버튼을 선택하면 실행하는 함수
 */
DirectMessageDetailViewMgr.Select = function()
{
	alert("DirectMessageDetailViewMgr.Select()");
	
	switch(this.current_index)
	{
		case 0:
            		//interactive remote start
			if(iRemoteTW.brwsrVer){
				 var showElements = null;
				showElements = {
					type : "qwerty",
					identifier : "qwertyDirRep",
					title : TWID_REPLY,
					onEvent : "action?dirReply=[$qwertyDirRep.value$]"
				}
				$.sfIRemote('menu', showElements);
			}
			//interactive remote end
			DirectMessageIME.Show(this.current_status, 
							  	  function()
								  {
								  	LoadingMgr.Show();
								  	KeyHandler.FocusNoKey();
								  	if(DirectMessagesMgr.GetMode() == 100)
									{
										DirectMessages.SetGetSentDirectMessageReturnFunc(
											DirectMessageDetailViewMgr.OnGetSentDirectMessagesSuccessful1);
										DirectMessages.GetSentDirectMessages(1, true);
									}
									else if(DirectMessagesMgr.GetMode() == 101)
									{
										DirectMessages.SetGetSentDirectMessageReturnFunc(
											DirectMessageDetailViewMgr.OnGetSentDirectMessagesSuccessful2);
										DirectMessages.GetSentDirectMessages(1, true);
									}
								  	
								  	DirectMessageIME.Hide();
									DirectMessageDetailViewMgr.Hide();

									//interactive remote start
									iRemoteTW.onLoad();
									iRemoteTW.directMessage();
									//interactive remote end
									
								  }, (DirectMessagesMgr.GetMode()==100 ? this.current_status.SenderScreenName : 
								  									   this.current_status.RecipientScreenName),
									102,(DirectMessagesMgr.GetMode()==100 ? this.current_status.Sender.Id : 
								  									   this.current_status.Recipient.Id));
			break;
		case 1:

			//interactive remote start
			iRemoteTW.yesNoPopup(SID_DELETE_THE_SELECTED_TWEET);
			//interactive remote end
			
			YesNoPopupMgr.ShowDelete(function(return_code)
						{
							alert("return_code -> " + return_code);
							 
							if(return_code == 0)
							{
								LoadingMgr.Show();
								KeyHandler.FocusNoKey();
								DirectMessageDetailViewMgr.Hide();
								DirectMessages.SetDeleteReturnFunc(DirectMessagesMgr.OnDelete);
								DirectMessages.Delete(DirectMessageDetailViewMgr.current_status.Id, true);
							}
							else
							{
								DirectMessageDetailViewMgr.Focus();	
							}
						});
						
			
			break;
		case 2:
			ProfileMgr.Show((this.mode == 100 ? this.current_status.Sender : this.current_status.Recipient), 
							function(pEvent)
							{
                                if (pEvent == TwitterDefine.Event.Success) {
									MainMenuMgr.Hide();
									DirectMessageDetailViewMgr.Hide();
									DirectMessagesMgr.Hide();
                                } else {
									DirectMessagesMgr.Focus();
								}

							}, 3);
			break;
	}	
}

/**
 * 다이렉트 메시지 상세보기의 키 핸들러
 */
DirectMessageDetailViewMgr.KeyHandler = function()
{
	if (!CUtil.delayKey()) return;
	alert("DirectMessageDetailViewMgr.KeyHandler() -> KeyCode : " + event.keyCode);
	switch (event.keyCode)
	{
		case tvKey.KEY_UP:
			DirectMessageDetailViewMgr.MoveUp();
			break;
					
		case tvKey.KEY_DOWN:
			DirectMessageDetailViewMgr.MoveDown();
			break;
			
		case tvKey.KEY_RETURN:
			widgetAPI.blockNavigation(event);
			DirectMessageDetailViewMgr.Hide();
			//DirectMessagesMgr.Display();
			DirectMessagesMgr.Refresh();
			DirectMessagesMgr.Focus();

		   	//interactive remote start
			iRemoteTW.onLoad();
		   	iRemoteTW.directMessage();
			//interactive remote end
			
			break;
			
		case tvKey.KEY_ENTER:
			DirectMessageDetailViewMgr.Select();
			break;
		/*
		case tvKey.KEY_BLUE:
			this.Hide();
			DirectMessagesMgr.Hide();
			MainMenuMgr.ShowHomeMenu();
			HomeMgr.Show();
			HomeMgr.Focus();
			break;
		*/
	}
}
