/**
 * 기본기능 팝업을 구현한 클래스
 * @class 기본기능 팝업을 구현한 클래스
 */
var HomePopupMgr = 
{
	current_index : 0,
	current_status : null,
	key_anchor : null,
	
	button_enable_table : null,
	
	COUNT_IN_MENUITEM : 5,
	
	mode : 1
}

/**
 * HomePopupMgr 초기화
 */
HomePopupMgr.Init = function()
{
	UIHomePopup.Init();
	
	this.key_anchor = document.getElementById("HomePopupKeyAnchor");
}

/**
 * 기본기능 팝업의 키 입력 포커스를 주는 함수
 */
HomePopupMgr.Focus = function()
{
	this.key_anchor.focus();
}

/**
 * 현재 모드를 얻는 함수
 * @return {Number} 1:Home, 2:People, 4:Search, 5:Profile>following/followers
 */
HomePopupMgr.GetMode = function()
{
	return this.mode;
}

/**
 * 기본기능 팝업을 화면에 표시한다.
 * @param {Number} x 팝업을 표시할 X좌표
 * @param {Number} y 팝업을 표시할 Y좌표
 * @param {Object} status 해당 Status
 * @param {Number} mode 1:Home, 2:People, 4:Search, 5:Profile>following/followers
 */
HomePopupMgr.Show = function(x,y, status, mode)
{
	this.current_index = 0;
	this.current_status = status;
	this.mode = mode;

	alert("HomePopupMgr.Show() -> " + this.mode);
	this.button_enable_table=new Array();
	for(var i=0; i<this.COUNT_IN_MENUITEM; i++)
		this.button_enable_table[i] = true;
	
	if ((this.current_status.UserId ? this.current_status.UserId : this.current_status.Id) == TwitterMain.SessionUID)
	{
		UIHomePopup.DisableProfile();
		UIHomePopup.DisableUnfollow();
		UIHomePopup.DisableBlock();
		this.button_enable_table[0] = false;
		this.button_enable_table[3] = false;
		this.button_enable_table[4] = false;
	}
	else
	{
		UIHomePopup.EnableProfile();
		UIHomePopup.EnableUnfollow();
		UIHomePopup.EnableBlock();
	}
	
	if (People.ContainFollowersId(this.current_status.UserId)) 
		UIHomePopup.EnableDirectMessage();
	else 
	{
		UIHomePopup.DisableDirectMessage();
		this.button_enable_table[2] = false;
	}
	
	if (People.ContainFollowingId(this.current_status.UserId)) {
		UIHomePopup.SetUnfollowText();
	} else {
		UIHomePopup.SetFollowText();
	}
	
	while(!this.button_enable_table[this.current_index] 
		  && this.current_index < this.COUNT_IN_MENUITEM )
		this.current_index++;
	UIHomePopup.Display();
	UIHomePopup.Show(x,y);
	this.Focus();
}

/**
 * 기본기능 팝업을 화면 숨기는 함수
 */
HomePopupMgr.Hide = function()
{
	UIHomePopup.Hide();

	//interactive remote start
	iRemoteTW.popupOff();
	//interactive remote end
}

/**
 * 포커스의 위치를 얻는 함수
 */
HomePopupMgr.GetFocusLocation = function()
{
	return this.current_index;
}

/**
 * 포커스를 하나 위로 올리는 함수
 */
HomePopupMgr.MoveUp = function()
{
	do
	{
		this.current_index--;
		if(this.current_index < 0)
			this.current_index=this.COUNT_IN_MENUITEM-1;
	}while(!this.button_enable_table[this.current_index]);
	UIHomePopup.Display();
}

/**
 * 포커스를 하나 아래로 내리는 함수
 */
HomePopupMgr.MoveDown = function()
{
	do
	{
		this.current_index++;
		if(this.current_index >= this.COUNT_IN_MENUITEM)
			this.current_index=0;
	}while(!this.button_enable_table[this.current_index]);
	UIHomePopup.Display();
}

/**
 * Unfollow를 성공한 후 호출되는 콜백함수
 */
HomePopupMgr.OnFriendShipsDestroySuccessful = function()
{
	alert("HomePopupMgr.OnFriendShipsDestroySuccessful()");
	alert("Unfollow 성공");	
	LoadingMgr.Hide();
	HomePopupMgr.Hide();
   
    	//interactive remote start
	iRemoteTW.messgPopup("",SID_YOU_ARE_NOW_NO_LONGER_FOLLOWING.Replace(HomePopupMgr.current_status.ScreenName)); 
	//interactive remote end
	MessageBoxMgr.Show("", SID_YOU_ARE_NOW_NO_LONGER_FOLLOWING.Replace(HomePopupMgr.current_status.ScreenName),
						   function()
						   {
								People.RemoveFollowingID(HomePopupMgr.current_status.UserId);
							   	if (HomePopupMgr.mode == 1) 
								{
									//HomeMgr.Refresh();
									PeopleMgr.SetUpdate(1);
									HomeMgr.SetUpdate(0);
									HomeMgr.SetUpdate(1);
									HomeMgr.SetUpdate(2);
									HomeMgr.Show();
								}
								else if(HomePopupMgr.mode == 2)
								{
									PeopleMgr.Refresh();
									HomeMgr.SetUpdate(0);
									HomeMgr.SetUpdate(1);
									HomeMgr.SetUpdate(2);
									PeopleMgr.SetUpdate(1);
									PeopleMgr.Show();
								}
								else if (HomePopupMgr.mode ==  TwitterDefine.From.Wave) {
									PeopleMgr.SetUpdate(1);
									ProfilePeopleMgr.Refresh();
									ProfilePeopleMgr.Focus();
								}
								else if (HomePopupMgr.mode ==  TwitterDefine.From.Search) {
									SearchMgr.Refresh();
									PeopleMgr.SetUpdate(1);
									PeopleMgr.SetUpdate(2);
									HomeMgr.SetUpdate(0);
									HomeMgr.SetUpdate(1);
									HomeMgr.SetUpdate(2);
									SearchMgr.Focus();
								}
						   });
	
}

/**
 * Unfollow를 성공한 후 호출되는 콜백함수
 */
HomePopupMgr.OnFriendShipsCreateSuccessful = function()
{
	alert("HomePopupMgr.OnFriendShipsCreateSuccessful()");
	alert("Follow 성공");	
	LoadingMgr.Hide();
	HomePopupMgr.Hide();
	//interactive remote start
	iRemoteTW.messgPopup("",TEMPID_HOMEPOPUP_FRIENDSHIP_CREATE_MSG.Replace(HomePopupMgr.current_status.ScreenName)); 
	//interactive remote end
	MessageBoxMgr.Show("", TEMPID_HOMEPOPUP_FRIENDSHIP_CREATE_MSG.Replace(HomePopupMgr.current_status.ScreenName),
						   function()
						   {
								People.AddFollowingID(HomePopupMgr.current_status.UserId);
							   	if (HomePopupMgr.mode == 1) 
								{
									PeopleMgr.SetUpdate(1);
									HomeMgr.SetUpdate(0);
									HomeMgr.SetUpdate(1);
									HomeMgr.SetUpdate(2);
									HomeMgr.Show();
								}
								else if(HomePopupMgr.mode == 2)
								{
									PeopleMgr.Refresh();
									HomeMgr.SetUpdate(0);
									HomeMgr.SetUpdate(1);
									HomeMgr.SetUpdate(2);
									PeopleMgr.SetUpdate(1);
									PeopleMgr.Show();
								}								
								else if (HomePopupMgr.mode ==  TwitterDefine.From.Wave) {
									PeopleMgr.SetUpdate(1);
									ProfilePeopleMgr.Refresh();
									ProfilePeopleMgr.Focus();
								}
								else if (HomePopupMgr.mode ==  TwitterDefine.From.Search) {
									SearchMgr.Refresh();
									PeopleMgr.SetUpdate(1);
									PeopleMgr.SetUpdate(2);
									HomeMgr.SetUpdate(0);
									HomeMgr.SetUpdate(1);
									HomeMgr.SetUpdate(2);
									SearchMgr.Focus();
								}
						   });
	
}

/**
 * Block을 성공한 후 호출되는 콜백함수
 */
HomePopupMgr.OnBlocksCreateSuccessful = function()
{
	alert("HomePopupMgr.OnBlocksCreateSuccessful()");
	alert("Block 성공");	
	LoadingMgr.Hide();
	HomePopupMgr.Hide();
   
	//interactive remote start
	iRemoteTW.messgPopup("", SID_YOU_ARE_NOW_NO_LONGER_FOLLOWING.Replace(HomePopupMgr.current_status.ScreenName)); 
	//interactive remote end
	MessageBoxMgr.Show("", SID_YOU_ARE_NOW_NO_LONGER_FOLLOWING.Replace(HomePopupMgr.current_status.ScreenName),
					   function()
					   {
							if (HomePopupMgr.mode == 1) 
							{
								HomeMgr.Refresh();
								HomeMgr.SetUpdate(0);
								HomeMgr.SetUpdate(1);
								HomeMgr.SetUpdate(2);
								HomeMgr.Show();
							}
							else if(HomePopupMgr.mode == 2)
							{
								PeopleMgr.Refresh();
								//PeopleMgr.current_index = 0;
								//PeopleMgr.current_page = 1;
								PeopleMgr.SetUpdate(1);
								PeopleMgr.SetUpdate(2);
								HomeMgr.SetUpdate(0);
								HomeMgr.SetUpdate(1);
								HomeMgr.SetUpdate(2);
								PeopleMgr.Show();
							}
							else if(HomePopupMgr.mode == 4)
							{
								SearchMgr.Refresh();
								PeopleMgr.SetUpdate(1);
								PeopleMgr.SetUpdate(2);
								HomeMgr.SetUpdate(0);
								HomeMgr.SetUpdate(1);
								HomeMgr.SetUpdate(2);
								SearchMgr.Focus();
							}
							else if(HomePopupMgr.mode == 5)
							{
								ProfilePeopleMgr.Refresh();
								PeopleMgr.SetUpdate(1);
								PeopleMgr.SetUpdate(2);
								HomeMgr.SetUpdate(0);
								HomeMgr.SetUpdate(1);
								HomeMgr.SetUpdate(2);
								ProfilePeopleMgr.Focus();
							}				   	
					   });
		
	
}

/**
 * 기본기능 팝업에서의 API 요청이 실패한 후 실행되는 콜백함수 
 */
HomePopupMgr.OnFailed = function()
{
	alert("HomePopupMgr.OnFailed()");
	LoadingMgr.Hide();

	//interactive remote start
	 iRemoteTW.messgPopup("", SID_ALERT_NETWORKERROR_MSG); 
	 //interactive remote end
	MessageBoxMgr.Show("", SID_ALERT_NETWORKERROR_MSG,
						   function()
						   {
								if(HomePopupMgr.mode == 1)
								{
									HomeMgr.Refresh();
									HomeMgr.Focus();
									HelpNavigationMgr.ShowHomeHelp();
								}
								else if(HomePopupMgr.mode == 2)
								{
									PeopleMgr.Refresh();
									PeopleMgr.Focus();
									HelpNavigationMgr.ShowPeopleHelp();
								}
								else if(HomePopupMgr.mode == 4)
								{
									SearchMgr.Refresh();
									SearchMgr.Focus();
								}
								else if(HomePopupMgr.mode == 5)
								{
									ProfilePeopleMgr.Refresh();
									ProfilePeopleMgr.Focus();	
								}
						   });
}

/**
 * Block이 실패한 후 실행되는 콜백함수
 */
HomePopupMgr.OnBlockFailed = function()
{
	alert("HomePopupMgr.OnBlockFailed()");
	LoadingMgr.Hide();

	//interactive remote start
	 iRemoteTW.messgPopup("", SID_ALERT_NETWORKERROR_MSG); 
	 //interactive remote end
	MessageBoxMgr.Show("", SID_ALERT_NETWORKERROR_MSG,
						   function()
						   {
								if(HomePopupMgr.mode == 1)
								{
									HomeMgr.Focus();
									HelpNavigationMgr.ShowHomeHelp();
								}
								else if(HomePopupMgr.mode == 2)
								{
									PeopleMgr.Focus();
									HelpNavigationMgr.ShowPeopleHelp();
								}
						   });
}

/**
 * 선택한것에 따라 기능을 수행하는 함수
 */
HomePopupMgr.Select = function()
{
	switch(this.current_index)
	{
		case 0:
			ProfileMgr.Show(this.current_status, function(pEvent){
				if (pEvent == TwitterDefine.Event.Success) {
					HomePopupMgr.Hide();
					if (HomePopupMgr.mode == 1) 
						HomeMgr.Hide();
					else if (HomePopupMgr.mode == 2) 
						PeopleMgr.Hide();
					else if (HomePopupMgr.mode == 3)
						DirectMessagesMgr.Hide();
					else if (HomePopupMgr.mode == 4) 
						SearchMgr.Hide();
					else if (HomePopupMgr.mode == 5) {
						ProfilePeopleMgr.Hide();
					} else if (HomePopupMgr.mode == TwitterDefine.From.Wave) {
						ProfilePeopleMgr.Hide();
					}
					MainMenuMgr.Hide();
				} else {
					HomePopupMgr.Focus();
				}
			}, this.mode);
			break;
		case 1:
			this.Hide();
			//interactive remote start
			if (iRemoteTW.brwsrVer) {
				var showElements = null;
				showElements = {
					type: "qwerty",
					identifier: "qwertyHomeMen",
					title: TWID_MENTION,
					onEvent: "action?HomeMen=[$qwertyHomeMen.value$]"
				}
				$.sfIRemote('menu', showElements);
			}
			//interactive remote end
			var fnReturn = null;
				switch(this.mode) {
					case TwitterDefine.From.Home: 
						fnReturn =  function() {
											//interactive remote start
											iRemoteTW.onLoad();
											//interactive remote end
											HomePopupMgr.Hide();
											HomeMgr.Display()
											HelpNavigationMgr.ShowHomeHelp();
											HomeMgr.Focus();
									   };
						break;
					case TwitterDefine.From.People: 
						fnReturn = function() {
											//interactive remote start
											iRemoteTW.onLoad();
											//interactive remote end
											HomePopupMgr.Hide();
											PeopleMgr.Display();
											HelpNavigationMgr.ShowPeopleHelp();
											PeopleMgr.Focus();
									   }
						break;
					case TwitterDefine.From.Search: 
						fnReturn = function() {
											//interactive remote start
											iRemoteTW.onLoad();
											//interactive remote end
											HomePopupMgr.Hide();
											SearchMgr.Display();
											UISearch.Show();
											HelpNavigationMgr.ShowSearchHelp();
											SearchMgr.Focus();
									   }
						break;
					case TwitterDefine.From.ProfileSearch: 
						fnReturn = function()
									   {
											//interactive remote start
											iRemoteTW.onLoad();
											//interactive remote end   
											HomePopupMgr.Hide();
											ProfilePeopleMgr.Display();
											HelpNavigationMgr.ShowProfilePeopleHelp();
											ProfilePeopleMgr.Focus();
									   }
						break;
				}
				if (fnReturn) {
				MultilineIME.Show(this.current_status
					, function(pInputText){
						TwitterReply.OnEnter(HomePopupMgr.current_status.Id, pInputText, HomePopupMgr.mode, SID_TWEET_POSTED)
					}
					, function(){
						fnReturn();
					}
					, TWID_MENTION
					, TWID_MENTION + " " + this.current_status.ScreenName
					, "@" + this.current_status.ScreenName + " ");
			}
			break;
		case 2:
			//if (People.ContainDirectMessagesUser(this.current_status.UserId))
			
			if(People.ContainFollowersId(this.current_status.UserId)) 
			{
				this.Hide();	
			//interactive remote start
			if (iRemoteTW.brwsrVer) {
				var showElements = null;
				showElements = {
					type: "qwerty",
					identifier: "qwertyHpmDirMssg",
					title: TWID_DIRECT_MESSAGE,
					onEvent: "action?HpmDirMssg=[$qwertyHpmDirMssg.value$]"
				}
				$.sfIRemote('menu', showElements);
			}
			//interactive remote end
				DirectMessageIME.Show(this.current_status, 
								  	  function()
									  {
									  	DirectMessageIME.Hide();
									  	var mode = DirectMessageIME.GetMode();
									  	if (mode == 1) 
										{

											//interactive remote start
											iRemoteTW.onLoad();
											//interactive remote end   
											HelpNavigationMgr.ShowHomeHelp();
											HomeMgr.Refresh();
											HomeMgr.Focus();
											 //interactive remote start
											iRemoteTW.home();
											//interactive remote end

										}
										else if(mode == 2)
										{

											//interactive remote start
											iRemoteTW.onLoad();
											//interactive remote end   
											HelpNavigationMgr.ShowPeopleHelp();
											PeopleMgr.Refresh();
											PeopleMgr.Focus();

											//interactive remote start
											iRemoteTW.people();
											//interactive remote end
										}
										else if(mode == 4)
										{
											HelpNavigationMgr.ShowSearchHelp();
											SearchMgr.Refresh();
											SearchMgr.Focus();
                                            						//interactive remote start
											if(TopicsMgr.current_index == -1){
												iRemoteTW.newTopicSearch();

                                            						}
                                            						else{

											   iRemoteTW.topicItemSearch();
                                            						}
											//interactive remote end
										}
										else if(mode == 5)
										{
											HelpNavigationMgr.ShowProfilePeopleHelp();
											ProfilePeopleMgr.Refresh();
											ProfilePeopleMgr.Focus();
											//interactive remote start
                                              						if(ProfilePeopleMgr.mode == 1){

												iRemoteTW.profilePeopleFollowing();
                                                					}
                                            						else if(ProfilePeopleMgr.mode == 2){

												iRemoteTW.profilePeopleFollowers();
                                                					}
											//interactive remote end
										}
									  }, this.current_status.ScreenName,this.mode,
									     this.current_status.UserId);
			}
			else
			{
				this.Hide();
                
				//interactive remote start
	 			iRemoteTW.messgPopup("", SID_YOU_CAN_SEND_DIRECT_MESSAGES_ONLY_TO_YOUR_FOLLOWERS); 
	 			//interactive remote end
				MessageBoxMgr.Show("", SID_YOU_CAN_SEND_DIRECT_MESSAGES_ONLY_TO_YOUR_FOLLOWERS,
								   	   function()
									   {
									   		var mode = HomePopupMgr.GetMode();
										  	if (mode == 1) 
											{

												//interactive remote start
												iRemoteTW.onLoad();
												//interactive remote end   
												HelpNavigationMgr.ShowHomeHelp();
												HomeMgr.Refresh();
												HomeMgr.Focus();
											}
											else if(mode == 2)
											{

												//interactive remote start
												iRemoteTW.onLoad();
												//interactive remote end   
												HelpNavigationMgr.ShowPeopleHelp();
												PeopleMgr.Refresh();
												PeopleMgr.Focus();

												//interactive remote start
												iRemoteTW.people();
												//interactive remote end
											}
											else if(mode == 4)
											{

												//interactive remote start
												iRemoteTW.onLoad();
												//interactive remote end   
												HelpNavigationMgr.ShowSearchHelp();
												SearchMgr.Refresh();
												SearchMgr.Focus();
												//interactive remote start
                                								if(TopicsMgr.current_index == -1){
												 	iRemoteTW.newTopicSearch();

                                                 						}
                                            							else{
													iRemoteTW.topicItemSearch();

                                                						}
												//interactive remote end

											}
											else if(mode == 5)
											{
												HelpNavigationMgr.ShowProfilePeopleHelp();
												ProfilePeopleMgr.Refresh();
												ProfilePeopleMgr.Focus();
												//interactive remote start
                                                 						if(ProfilePeopleMgr.mode == 1){
   
													iRemoteTW.profilePeopleFollowing();
                                                						}
                                            							else if(ProfilePeopleMgr.mode == 2){

													iRemoteTW.profilePeopleFollowers();
                                                						}
												//interactive remote end
											}
									   });
			}
			break;
		case 3:
				this.Hide();
				LoadingMgr.Show();
				KeyHandler.FocusNoKey();					
				Friendships.SetDestroyErrorFunc(HomePopupMgr.OnFailed);
				Friendships.SetCreateErrorFunc(HomePopupMgr.OnFailed);
				
				if (People.ContainFollowingId(this.current_status.UserId)) {
					Friendships.SetDestroyReturnFunc(HomePopupMgr.OnFriendShipsDestroySuccessful);
					Friendships.Destroy(HomePopupMgr.current_status.ScreenName);
				} else {
					Friendships.SetCreateReturnFunc(HomePopupMgr.OnFriendShipsCreateSuccessful);
					Friendships.Create(HomePopupMgr.current_status.ScreenName);
				}
				
			/*
			if (ID != this.current_status.ScreenName && !(this.mode==2 && PeopleMgr.GetMode()==2) &&
				this.mode!=5) 
			{
				this.Hide();
				LoadingMgr.Show();
				KeyHandler.FocusNoKey();
				Friendships.SetDestroyErrorFunc(HomePopupMgr.OnFailed);
				Friendships.SetDestroyReturnFunc(HomePopupMgr.OnFriendShipsDestroySuccessful);
				Friendships.Destroy(HomePopupMgr.current_status.ScreenName);
			}
			*/
			break;
			
		case 4:
			if ((this.current_status.UserId ? this.current_status.UserId : this.current_status.Id) != TwitterMain.SessionUID) 
			{
				this.Hide();
				YesNoPopupMgr.ShowBlock(function(return_code)
										{
											alert("return_code -> " + return_code);
											if(return_code == 0)
											{
												LoadingMgr.Show();
												KeyHandler.FocusNoKey();
												Blocks.SetCreateErrorFunc(HomePopupMgr.OnBlockFailed);
												Blocks.SetCreateReturnFunc(HomePopupMgr.OnBlocksCreateSuccessful);
												Blocks.Create(HomePopupMgr.current_status.ScreenName);
											}
											else
											{
												var mode = HomePopupMgr.GetMode();
											  	if (mode == 1) 
												{
													HelpNavigationMgr.ShowHomeHelp();
													HomeMgr.Refresh();
													HomeMgr.Focus();
												}
												else if(mode == 2)
												{
													HelpNavigationMgr.ShowPeopleHelp();
													PeopleMgr.Refresh();
													PeopleMgr.Focus();
												}
												else if(mode == 4)
												{
													HelpNavigationMgr.ShowSearchHelp();
													SearchMgr.Refresh();
													SearchMgr.Focus();
												}
												else if(mode == 5)
												{
													HelpNavigationMgr.ShowProfilePeopleHelp();
													ProfilePeopleMgr.Refresh();
													ProfilePeopleMgr.Focus();
												}
											}
										});
				
			}
			break;
	}
}

/**
 * 기본기능 팝업의 키 핸들러
 */
HomePopupMgr.KeyHandler = function()
{
	if (!CUtil.delayKey()) return;
	alert("HomePopupMgr.KeyHandler() -> KeyCode : " + event.keyCode);
	switch (event.keyCode)
	{
		case tvKey.KEY_UP:
			this.MoveUp();
			break;
		case tvKey.KEY_DOWN:
			this.MoveDown();
			break;
		case tvKey.KEY_ENTER:
			
			this.Select();
			break;
		case tvKey.KEY_RETURN:
			widgetAPI.blockNavigation(event);
			this.Hide();
			
			if (this.mode == 1)  //홈 카테고리에서
			{
				//HomeMgr.Refresh();
				HomeMgr.Display();
				UIHome.Hide();
				UIHome.Show();
				HomeMgr.Focus();
			}
			else if(this.mode == 2) //People 카테고리에서
			{
				HelpNavigationMgr.ShowPeopleHelp();
				PeopleMgr.Refresh();
				PeopleMgr.Focus();
			}		
			else if(this.mode == 4) //Search(검색결과) 에서
			{
				SearchMgr.Refresh();
				SearchMgr.Focus();
			}
			else if(this.mode == 5) //profile>following or profile>followers 에서
			{
				ProfilePeopleMgr.Refresh();
				ProfilePeopleMgr.Focus();
			}
			else if (this.mode == TwitterDefine.From.Wave) {
				ProfilePeopleMgr.Refresh();
				ProfilePeopleMgr.Focus();				
			}
			break;
	}
}
