/**
 * 버튼 하나를 가진 메시지 박스를 구현한 클래스
 * @class 버튼 하나를 가진 메시지 박스를 구현한 클래스
 */
var MessageBoxMgr =
{
	func : null,
	timer : null,
	
	TIMEOUT : 5000,
	
	SCREEN_WIDTH : 960,
	SCREEN_HEIGHT : 540,
	MESSAGEBOX_WIDTH : 465,
	MESSAGEBOX_HEIGHT : 265,
	
	EXTRA_LEFT : 0,
	
	key_anchor : null
}

/**
 * MessageBoxMgr 초기화
 */
MessageBoxMgr.Init = function()
{
	alert("MessageBoxMgr.Init()");
	
	UIMessageBox.Init();
	
	this.key_anchor = document.getElementById("MessageBoxKeyAnchor");
}

/**
 * 메시지박스에 키 입력 포커스를 주는 함수
 */
MessageBoxMgr.Focus = function()
{
	this.key_anchor.focus();
}

/**
 * 화면에 메시지 박스를 표시하는 함수
 * @param {String} msg1 첫번째 줄에 표시할 문자열
 * @param {String} msg2 두번째 줄에 표시할 문자열
 * @param {Function} func 메시지 박스에서 버튼을 누른 후 실행할 함수
 */
MessageBoxMgr.Show = function(msg1, msg2, func, pTimeout)
{
	alert("MessageBoxMgr.Show()");
	
	this.func = func;
	
	var x = this.SCREEN_WIDTH / 2 - this.MESSAGEBOX_WIDTH / 2 + this.EXTRA_LEFT;
	var y = this.SCREEN_HEIGHT / 2 - this.MESSAGEBOX_HEIGHT / 2;
	UIMessageBox.Move(x, y);
	
	UIMessageBox.SetMessage1(msg1);
	UIMessageBox.SetMessage2(msg2);
	UIMessageBox.Show();
	this.Focus();
	
	if(this.timer)
	{
		clearTimeout(this.timer);
		this.timer = null;
	}
	this.timer = setTimeout("MessageBoxMgr.Hide()", pTimeout ? pTimeout : this.TIMEOUT);
}

/**
 * 메시지 박스를 화면에서 숨기는 함수
 */
MessageBoxMgr.Hide = function()
{
	if(this.timer)
	{
		clearTimeout(this.timer);
		this.timer = null;
	}
	if(this.func)
		this.func();
		
	UIMessageBox.Hide();

	//interactive remote start
	iRemoteTW.popupOff();
	//interactive remote end
}

/**
 * 메시지 박스의 키 핸들러
 */
MessageBoxMgr.KeyHandler = function()
{
	if (!CUtil.delayKey()) return;
	alert("MessageBoxMgr.KeyHandler() -> KeyCode : " + event.keyCode);
	switch (event.keyCode)
	{
		case tvKey.KEY_ENTER:
		case tvKey.KEY_RETURN:
			widgetAPI.blockNavigation(event);
			MessageBoxMgr.Hide();
			break;
		default:
			break;
	}
}
