/**
 * Topics 카테고리를 구현한 클래스
 * @class Topics 카테고리를 구현한 클래스
 */
var TopicsMgr =
{
	current_topic_list : null,
	current_topic_cut_list : null,
	
	current_index : 0,
	current_page : 1,
	
	key_anchor : null,
	is_first_show : true,
	
	SCROLLBAR_X : null,
	SCROLLBAR_Y : null,
	
	COUNT_IN_PAGE : 8
}

/**
 * TopicsMgr 초기화
 */
TopicsMgr.Init = function()
{
	alert("TopicsMgr.Init()");
	UITopics.Init();
	
	Topics.SetGetTopicsReturnFunc(TopicsMgr.OnGetTopicsSuccessful);
	
	this.key_anchor = document.getElementById("TopicsKeyAnchor");
}

/**
 * Topic 카테고리에서 하나를 선택한 후 기능을 수행하는 함수
 */
TopicsMgr.Select = function()
{
	switch(this.current_index)
	{
		case -1:
			//interactive remote start
			if (iRemoteTW.brwsrVer) {
				var showElements = null;
				showElements = {
					type: "qwerty",
					identifier: "qwertySear",
					title: SID_SEARCH,
					onEvent: "action?search=[$qwertySear.value$]"
				}
				$.sfIRemote('menu', showElements);
			}
			//interactive remote end
			SearchIME.SetReturnFocusFunc(this.key_anchor);
			SearchIME.Show(function(pResult)
						  {
						  	SearchIME.Hide();
							TopicsMgr.Show(true);

							//interactive remote start
							iRemoteTW.onLoad();
							iRemoteTW.topics();
							//interactive remote end
						  });
			break;
		default:
			SearchMgr.Show(this.current_topic_cut_list[this.current_index].name, true);
			break;
	}
}

/**
 * Topic 목록 받기를 성공한 후 실행되는 콜백함수
 * @param {Object} topic_list 받아온 토픽 목록
 */
TopicsMgr.OnGetTopicsSuccessful = function(topic_list)
{
	alert("TopicsMgr.OnGetTopicsSuccessful()");
	alert("토픽 받기 성공");
	TopicsMgr.current_topic_list = topic_list.trends;
	TopicsMgr.Display(TopicsMgr.current_topic_list);
	TopicsMgr.Focus();
	//UITopics.Hide();
	LoadingMgr.Hide();
    if (TopicsMgr.is_first_show) 
        TopicsMgr.is_first_show = false;
}

/**
 * Topic 목록을 얻어오는 함수
 */
TopicsMgr.GetTopics = function()
{
	Topics.GetTopics();
}

/**
 * 실제 포커스 인덱스를 구하는 함수
 */
TopicsMgr.GetRealIndex = function()
{
	return ((this.current_page-1)*this.COUNT_IN_PAGE+this.current_index);	
}

/**
 * Topic 카테고리를 화면에 표시하는 함수
 */
TopicsMgr.Show = function(pStayFocus)
{
	if (!pStayFocus) {
		this.current_index = 0;
		this.current_page = 1;
	}
	
	if(this.is_first_show)
	{
		LoadingMgr.Show();
		KeyHandler.FocusNoKey();
		Topics.GetTopics();
	}
	else
	{
		this.Display();
		TopicScrollBarMgr.Display(this.GetRealIndex(), this.current_topic_list.length);
		TopicScrollBarMgr.Show(this.SCROLLBAR_X, this.SCROLLBAR_Y);
		UITopics.Show();
		this.Focus();
	}
}

/**
 * Topic 카테고리를 화면에서 숨기는 함수
 */
TopicsMgr.Hide = function()
{
	UITopics.Hide();
	TopicScrollBarMgr.Hide();
	HelpNavigationMgr.HideTopicsHelp();
	PageIndicatorMgr.Hide();
}

/**
 * 현재 포커스 인덱스를 구하는 함수
 */
TopicsMgr.GetFocusLocation = function()
{
	return this.current_index;
}

/**
 * 화면에 보일 갯수 만큼만 리스트를 자르는 함수
 */
TopicsMgr.CutList = function()
{
	var lowerbound = (this.current_page-1) * this.COUNT_IN_PAGE;
	var upperbound = (this.current_page-1) * this.COUNT_IN_PAGE + this.COUNT_IN_PAGE;
	
	alert("TopicsMgr.CutList() -> "+lowerbound+" "+upperbound);
	var list = new Array();
	for(var i=lowerbound; i<upperbound; i++)
	{
		if(this.current_topic_list[i])
			list[list.length] = this.current_topic_list[i];
	}
	
	this.current_topic_cut_list = list;
}

/**
 * 실제 Topics 카테고리 내용을 그리는 함수
 */
TopicsMgr.Display = function()
{
	this.CutList();	
	PageIndicatorMgr.SetIndicatorText(this.current_page,Math.floor((this.current_topic_list.length-1)/this.COUNT_IN_PAGE)+1);
	PageIndicatorMgr.Show(null,172);
	if (this.current_index > -1) 
	{
		TopicScrollBarMgr.Display(this.GetRealIndex(), this.current_topic_list.length);
		TopicScrollBarMgr.Show(this.SCROLLBAR_X, this.SCROLLBAR_Y);
	}
	UITopics.Display(this.current_topic_cut_list);

	//interactive remote start
	iRemoteTW.topics();
	//interactive remote end
}

/**
 * 포커스를 하나 위로 이동시키는 함수
 */
TopicsMgr.MoveUp = function()
{
	this.current_index--;
	if (this.current_page==1 && this.current_index < -1) 
	{
		this.current_page = 2;
		this.current_index = 1;
	}
	else if(this.current_page==2 && this.current_index < 0)
	{
		this.current_page = 1;
		this.current_index = this.COUNT_IN_PAGE-1;
	}
		
	this.Display();
}

/**
 * 포커스를 하나 아래로 이동시키는 함수
 */
TopicsMgr.MoveDown = function()
{
	this.current_index++;
	
	if(this.current_page == 2 && this.current_index >= 2)
	{
		this.current_page = 1;
		this.current_index = -1;
	}
	else if(this.current_page == 1 && this.current_index >= this.COUNT_IN_PAGE)
	{
		this.current_page = 2;
		this.current_index = 0;
	}
	
	this.Display();
}

/**
 * 이전 페이지로 이동하는 함수
 */
TopicsMgr.PageUp = function()
{
	alert("TopicsMgr.PageUp() -> " + this.current_index);
	this.current_page--;
	if (this.current_page <= 0) 
	{
		this.current_page = 2;
	}
	this.current_index = 0;
	this.Display();
}

/**
 * 다음 페이지로 이동하는 함수
 */
TopicsMgr.PageDown = function()
{
	alert("TopicsMgr.PageDown() -> " + this.current_index);
	this.current_page++;
	var total_page = Math.floor(this.current_topic_list.length/this.COUNT_IN_PAGE) + 1;
	alert(total_page);
	if (this.current_page > total_page) 
	{
		this.current_page = 1;
	}
	this.current_index = 0;
	this.Display();
}

/**
 * Topics 카테고리에 키 입력 포커스를 주는 함수
 */
TopicsMgr.Focus = function()
{
	this.key_anchor.focus();
}

//interactive remote start
TopicsMgr.RefreshList = function()
{
	this.current_page = 1;
	this.current_index = 0;

//	KeyHandler.FocusNoKey();
      //this.Init();
      TopicsMgr.GetList(-1);
  

    //Timeline.GetUserTimeline(ID, this.user_timeline_load_no, true);
}
TopicsMgr.GetList = function(cursor)
{
	LoadingMgr.Show();
	KeyHandler.FocusNoKey();
	var index = (this.current_page-1)*this.COUNT_IN_PAGE;
	
Topics.GetTopics(1); 
}
//interactive remote end
/**
 * Topics 카테고리의 키 핸들러
 */
TopicsMgr.KeyHandler = function()
{
	if (!CUtil.delayKey()) return;
	alert("TopicsMgr.KeyHandler() -> " + event.keyCode);
	switch (event.keyCode)
	{
		case tvKey.KEY_LEFT:
			if (MainMenuMgr.ShowPrevMenu()) {
				this.Hide();
				DirectMessagesMgr.Show();
			}
			break;
		case tvKey.KEY_RIGHT:
			if (MainMenuMgr.ShowNextMenu()) {
				this.Hide();
				MoreMgr.Show();
			}
			break;
		case tvKey.KEY_UP:
			this.MoveUp();
			break;
		case tvKey.KEY_DOWN:
			this.MoveDown();
			break;
		case tvKey.KEY_RW:
			this.PageUp();
            break;
        case tvKey.KEY_FF:
			this.PageDown();
            break;
		case tvKey.KEY_RETURN:
			break;
		case tvKey.KEY_BLUE:
			break;
		case tvKey.KEY_ENTER:
			this.Select();
			break;
	}
}
