/**
 * Debug Message 출력
 * @param {String} 출력할 Message
 * @return null
 */
function TWAlert(pMsg) { alert("[Twitter Widget] " + pMsg); }
function TWAlert_(pMsg) { alert("[Twitter Widget(Fatal)] " + pMsg); }

/**
 * XML 노드에서 데이터 값 얻음
 * @param {Object} node XML 노드
 * @return {String} 성공하면 XML 노드 데이터, 실패하면 빈 문자열
 */
function GetXmlNodeData(node)
{
	if(node[0].hasChildNodes())
		return node[0].firstChild.data;
	
	return "";
}

/**
 * 어느 클래스에서나 공통적으로 쓰이는 루틴을 모아놓은 클래스
 * @class 어느 클래스에서나 공통적으로 쓰이는 루틴을 모아놓은 클래스
 */
var Util =
{
	TWITPIC_URL : "http://twitpic.com",
	TWITPIC_TEXT: "TwitPic"
}


/**
 * String replacement
 * @param 	{ String }	Original string
 * @param 	{ Object }	Condition ( Format : { 'Target Text' : 'Modified Text' } )
 * @return 	{ String } 	Modified string
 */
Util.strReplace = function(pStr, pCondition) {
	try {
		for (var source in pCondition) {
			pStr.replace(source, pCondition[source]);
		}
		return pStr;
	} catch (e) {
		return e;
	}
}

Util.encodeURI = function (s) {
    if (s == null) {
        return "";
    }
    if (s instanceof Array) {
        var e = "";
        for (var i = 0; i < s.length; ++s) {
            if (e != "") e += '&';
            e += OAuth.percentEncode(s[i]);
        }
        return e;
    }
    s = encodeURIComponent(s);
    // Now replace the values which encodeURIComponent doesn't do
    // encodeURIComponent ignores: - _ . ! ~ * ' ( )
    // OAuth dictates the only ones you can ignore are: - _ . ~
    // Source: http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Functions:encodeURIComponent
    s = s.replace(/\!/g, "%21");
    s = s.replace(/\*/g, "%2A");
    s = s.replace(/\'/g, "%27");
    s = s.replace(/\(/g, "%28");
    s = s.replace(/\)/g, "%29");
    return s;
}

/**
 * Tweet글에서 TwitPic 이미지 ID 추출
 * @param {String} text TwitPic에서 Twitter로 자동으로 등록된 tweet 글
 * @return {String} TwitPic 이미지 ID
 */
Util.ExtractTwitpicImageId = function(text)
{
	
	var res = "";
	if(text.indexOf(this.TWITPIC_URL)!=-1)
	{
		var s1 = text.indexOf(this.TWITPIC_URL)+this.TWITPIC_URL.length+1;
		var s2 = text.indexOf("-",text.indexOf(this.TWITPIC_URL)+this.TWITPIC_URL.length+1);
		res = text.substr(s1,s2-s1-1);
	}
	
	alert("Util.ExtractTwitpicImageId() -> " + res);
	
	return res;
}

/**
 * Tweet글이 TwitPic에서 올라온 글인지 판단
 * @param {String} text Tweet글
 * @param {String} from Status의 Source데이터
 * @return {boolean} true:TwitPic에서 올라온 글, false:TwitPic에서 올라온 글이 아님 
 */
Util.IsFromTwitpic = function(text, from)
{
	var i;
	for(i=0;i<from.length;i++)
		if(from[i]=='>')
			break;
	var j;
	var source = "";
	for(j=i+1;j<from.length;j++)
		if(from[j]=='<' || from[j]=='>')
			break;
		else
			source += from[j];
		
	alert("Util.IsFromTwitpic() -> " + " " +text.indexOf(this.TWITPIC_URL) + " " + source)
	
	if(text.indexOf(this.TWITPIC_URL)!=-1 && source==this.TWITPIC_TEXT)
		return true;
	
	return false;
}

/**
 * Array에서 index요소를 제거
 * @param {Object} arr index요소를 제거할 Array
 * @param {Object} index 제거할 인덱스, 0부터 시작
 * @return {Array} index요소를 제거한 Array 
 */
Util.RemoveArrayElementAt = function(arr, index)
{
	alert("Util.RemoveArrayElementAt()1 -> "+arr.length);
	var arr_head = arr.slice(0, index);
	var arr_body = arr.slice(index + 1);
	
	for (var i = 0; i < arr_body.length; i++) 
		arr_head.push(arr_body[i]);
	
	arr = arr_head;
	
	alert("Util.RemoveArrayElementAt()2 -> "+arr_head.length);
	return arr_head;
}

Util.RemoveArrayElement = function(arr, pKeyword)
{
	var tempArr = new Array();
	if (arr instanceof Array) {
		var length = arr.length;
		for (var idx = 0; idx < length; idx++) {
			if (arr[idx] != pKeyword) 
				tempArr.push(arr[idx]);
		}
	}
	return tempArr;
}

/**
 * Div에 이미지를 넣음
 * @param {Object} div DIV객체
 * @param {String} image_path 이미지의 경로
 * @param {Number} width 이미지의 너비
 * @param {Number} height 이미지의 높이
 */
Util.SetImageToDiv = function(div, image_path,width,height)
{
	var tmp = "";
	tmp += "<img src='" + image_path + "' width='" + width + "' height='" + height + "'>";
		   
	widgetAPI.putInnerHTML(div, tmp);			
}

/**
 * CSS클래스를 DIV객체에 적용
 * @param {Object} div DIV객체
 * @param {String} class_name CSS클래스 이름
 */
Util.SetClassToDiv = function(div, class_name)
{
	div.className = class_name; 
}

/**
 * 밀리세컨드를 분으로 변환
 * @param {Number} ms 밀리세컨드 값
 * @return {Number} 변환된 분 값
 */
Util.ConvertMSToMinutes = function(ms)
{
	return ms/1000/60;
}

/**
 * 밀리세컨드를 시간으로 변환
 * @param {Number} ms 밀리세컨드 값
 * @return {Number} 변환된 시간 값
 */
Util.ConvertMSToHours = function(ms)
{
	return ms/1000/60/60;
}

/**
 * 숫자로 들어오는 월 값을 영어 월 세글자로 변환
 * @param {Number} mon 숫자로 들어오는 월 수
 * @return {String} 세글자 영어 월 
 */
Util.ConvertMonthToString = function(mon)
{
	switch(mon)
	{
		case 1:
			return "Jan";
		case 2:
			return "Feb";
		case 3:
			return "Mar";
		case 4:
			return "Apr";
		case 5:
			return "May";
		case 6:
			return "Jun";
		case 7:
			return "Jul";
		case 8:
			return "Aug"; 
		case 9:
			return "Sep";
		case 10:
			return "Oct"; 
		case 11:
			return "Nov";
		case 12:
			return "Dec";
	}
	return ""; 
}

/**
 * 날짜의 일 값을 서수로 변환. 예) date : 1, return : 1st
 * @param {Number} date 날짜의 일 값
 * @return {Number} 서수로 변환된 숫자 값
 */
Util.ConvertDateToString = function(date)
{
	if(date == 1)
		return date + "st";
	else if(date == 2)
		return date + "nd";
	else if(date == 3)
		return date + "rd";
	else 
		return date + "th";	
}

/**
 * Status와 Date를 이용하여 about X hours ago from SOURCE 형식으로 문자열 만듦
 * @param {Status} status 해당 Status
 * @param {Date} date 해당 날짜 
 * @return {String} about X hours ago from SOURCE 형식의 문자열
 */
Util.ExtractMessage = function(status, date){
	if (date == null) 
		return "";
	
	var now = new Date();
	var tmp_ms = now.getTime() - date.getTime();
	
	var hours = Util.ConvertMSToHours(tmp_ms);
	var minutes = Util.ConvertMSToMinutes(tmp_ms);
	var DEFINE = { FREE : 0, HOUR : 1, MINUTE : 2 }
	
	var nCategory = DEFINE.FREE;
	var bSingle = false;
	var strTime = "";
	
	if (hours >= 24) {
		nCategory = DEFINE.FREE;
		var tmp_hours = "" + (date.getHours() >= 13 ? date.getHours() - 12 : date.getHours());
		strTime += (tmp_hours.length == 1 ? "0" + tmp_hours : tmp_hours);
		strTime += ":";
		var tmp_minutes = "" + date.getMinutes();
		strTime += (tmp_minutes.length == 1 ? "0" + tmp_minutes : tmp_minutes) + " ";
		strTime += date.getHours() >= 12 ? SID_PM : SID_AM;
		strTime += " " + Util.ConvertMonthToString(date.getMonth() + 1) + " " + Util.ConvertDateToString(date.getDate());
	}
	else 
		if (minutes >= 60) {
			nCategory = DEFINE.HOUR;
			bSingle = (hours == 1) ? true : false;
			strTime = Math.round(hours);
		}
		else {
			nCategory = DEFINE.MINUTE;
			bSingle = (minutes == 1) ? true : false;
			strTime = Math.round(minutes);
		}
	
	var strReturn = "";
	var strAppName = status ? getSource(status) : "";
	
	switch(nCategory) {
		case DEFINE.FREE :
			strReturn = strTime;
			break;
		case DEFINE.HOUR :
			strReturn = bSingle ? TWID_ABOUT_A_HOUR_AGO
									: TWID_ABOUT_HOURS_AGO.Replace(strTime);
			break;
		case DEFINE.MINUTE :
			strReturn = bSingle ? TWID_ABOUT_A_MINUTE_AGO
									: TWID_ABOUT_MINUTES_AGO.Replace(strTime);			
			break;
		default:
			TWAlert("Util.ExtractMessage : Invalid category");
			break; 
	}
	
	strReturn = strAppName ? (strReturn + " " + TWID_FROM.Replace(strAppName)) : strReturn;
	
	return strReturn;
	
	function getSource(pStatus){
		var strSource = status.Source;
		var strName = "";
		
		if (strSource.indexOf("</a>") != -1) {
			var start = false;
			
			for (i = 0; i < strSource.length; i++) {
				if (start) 
					strName += strSource[i];
				if (strSource[i] == '>') 
					start = true;
				else 
					if (i + 1 < strSource.length && strSource[i + 1] == '<') 
						start = false;
			}
		}
		else 
			strName = strSource;
			
		return strName;
	}
}

/**
 * User와 Date를 이용하여 about X hours ago from SOURCE 형식으로 문자열 만듦
 * @param {User} user 해당 User
 * @param {Date} date 해당 날짜 
 * @return {String} about X hours ago from SOURCE 형식의 문자열
 */
Util.ExtractMessageFromUser = function(user, date)
{
	return Util.ExtractMessage(user.Status, date);
}

/**
 * DirectMessage Status와 Date를 이용하여 about X hours ago from SOURCE 형식으로 문자열 만듦
 * @param {DirectMessage} status 해당 DirectMessage Status
 * @param {Date} date 해당 날짜 
 * @return {String} about X hours ago from SOURCE 형식의 문자열
 */
Util.ExtractMessageFromDirectMessage = function(status, date)
{
	return Util.ExtractMessage(null, date);
}

Util.traverse = function(pObject) {
	var nDepth = 0;
	TWAlert_("[Object Traverse]");
	TWAlert_(recurPrint(nDepth,pObject,""));
	function recurPrint(nDepth, pObject, pStr) {
		if (pObject instanceof Array) {
			var itemLength = pObject.length;
			for (var itemIdx = 0; itemIdx < itemLength; itemIdx++) {
				pStr+="\n";
				for (var i = 0; i < nDepth; i++) pStr+= "  ";
				pStr += "Array[" + itemIdx + "]";
				pStr = recurPrint(nDepth+1, pObject[itemIdx],pStr);
			}
			return pStr;
		} else {
			if (typeof(pObject) != "object" || pObject == null) {
				pStr+="\n";
				for (var i = 0; i < nDepth; i++) pStr+= "  ";
				return pStr + "Value[" + pObject + "]";
			} else {
				for (var name in pObject) {
					pStr+="\n";
					for (var i = 0; i < nDepth; i++) pStr+= "  ";
					pStr += "Name[" + name + "]";
					pStr = recurPrint(nDepth+1, pObject[name], pStr);
				}
				return pStr;
			}
		}
	}
}

Util.seperateString = function(pString, pUnit) {
	if (!pString) return "";
	
	var strString = Util.convertHTMLtoText(pString);
	
	var nSeperateUnit = pUnit ? pUnit : 25;
	var nStringLength = strString.length;
	
	if (nStringLength < nSeperateUnit) return strString;
	
	var nCount = 0;
	var strReturn = "";
	for (var charIdx = 0; charIdx < nStringLength; charIdx++) {
		nCount++;
		strReturn += strString[charIdx];
		if (nCount == nSeperateUnit) {
			strReturn += "<wbr></wbr>";
			nCount = 0;
		}
	}
	return strReturn;
}

Util.convertHTMLtoText = function(pHTML) {
	return pHTML.replace(/&quot;/gi,"\"").replace(/&amp;/gi,"&").replace(/&lt;/gi,"<").replace(/&gt;/gi,">").replace(/&nbsp;/gi," ");
}

// Replace text with given keyword
Util.replaceString = function(pString, pArgs) {
	var nArgLength = pArgs.length < 6 ? pArgs.length : 5;
	for(var idx = 0; idx < nArgLength; idx++) {
		pString = pString.replace(Util.replaceString.arrSource[idx], pArgs[idx]);
	}
	return pString;
}

Util.replaceString.arrSource = ["<<A>>","<<B>>","<<C>>","<<D>>","<<E>>"];

String.prototype.toSeperate = function(pUnit){	return Util.seperateString(this, pUnit); }
String.prototype.Replace = function() {	return Util.replaceString(this, arguments); }
String.prototype.toHTML = function() {	return Util.convertHTMLtoText(this); }

Util.T9WordBoxPos = function(pInputObj) {
	try {	
		pInputObj.setWordBoxPos(135, 20);
	} catch (e) {
		alert("This model doesn't support T9");
	}
}
